@@ -10,9 +10,6 @@ from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext
 
 
-logger = logging.getLogger(__name__)
-
-
 class S3FileInput(ClearableFileInput):
     needs_multipart_form = False
     signing_url = reverse_lazy('s3file-sign')
@@ -55,9 +52,7 @@ class S3FileInput(ClearableFileInput):
 
     def value_from_datadict(self, data, files, name):
         url = data.get(name)
-        upload = files.get(name, None)
         if url:
-            logger.info(url)
             if url == 'initial':
                 return False
             filename = urllib2.unquote(urlparse(url).path)
@@ -66,7 +61,7 @@ class S3FileInput(ClearableFileInput):
                 return f
             except IOError:
                 return None
-        return upload
+        return None
 
     class Media:
         js = (
